# Pyntor::TUD - Slides in corporate design of Dresden University of Technology
# -*- coding: utf-8 -*-
# Copyright (C) 2006 Josef Spillner <josef@coolprojects.org>
# Published under GNU GPL conditions

import pygame
from pygame.locals import *

class TUDTitle:
	def __init__(self):
		self.faculty = None
		self.institute = None
		self.title = None
		self.titlecont = []
		self.author = None
		self.dateloc = None

class TUDSlide:
	def __init__(self):
		self.chapter = None
		#self.heading = None
		self.headings = []
		self.text = []

class TUD:
	def init(self, options):
		titlefile = options["title"]
		slidesfile = options["slides"]

		f = open(titlefile)
		titlelines = f.readlines()
		f.close()

		f = open(slidesfile)
		slideslines = f.readlines()
		f.close()

		self.title = TUDTitle()
		self.slides = []

		for line in titlelines:
			line = line.strip()
			if line == "" or line[0] == "#":
				continue
			param = line.split("=")
			if len(param) >= 2:
				keyword = param[0]
				value = "=".join(param[1:])
				#print keyword, ":", value

				if keyword == "faculty":
					self.title.faculty = value
				elif keyword == "institute":
					self.title.institute = value
				elif keyword == "title":
					self.title.title = value
				elif keyword == "titlecont":
					self.title.titlecont.append(value)
				elif keyword == "author":
					self.title.author = value
				elif keyword == "dateloc":
					self.title.dateloc = value
				else:
					print "(tud) warning: unkown keyword", keyword

		slide = TUDSlide()

		for line in slideslines:
			line = line.strip()
			if len(line) > 0 and line[0] == "#":
				continue
			if line == "***":
				self.slides.append(slide)
				slide = TUDSlide()
			elif len(line) > 0 and line[0] == "<" and line[-1] == ">":
				if slide.chapter:
					print "(tud) warning: duplicate chapter"
				slide.chapter = line[1:-1]
			elif len(line) > 0 and line[0] == "[" and line[-1] == "]":
				#if slide.heading:
				#	print "(tud) warning: duplicate heading"
				#slide.heading = line[1:-1]
				slide.headings.append(line[1:-1])
				slide.text.append(None)
			else:
				slide.text.append(line)

		if len(slide.text) > 0 or slide.chapter or slide.heading:
			self.slides.append(slide)

		self.pages = len(self.slides) + 1

	def render(self, screen, page, globalpage):
		coverpage = (page == 1)

		if coverpage:
			forecolor = (255, 255, 255)
			backcolor = (0x0b, 0x2a, 0x51)
			bannerforecolor = forecolor
		else:
			forecolor = (0x80, 0x80, 0x80)
			backcolor = (255, 255, 255)
			altforecolor = (0x0b, 0x2a, 0x51)
			bannerforecolor = altforecolor

		screen.fill(backcolor)

		# 131,151
		screen.fill(forecolor, ((0, 131), (1024, 1)))
		screen.fill(forecolor, ((0, 151), (1024, 1)))

		if coverpage:
			logo = pygame.image.load("tud/scaled.tudlogo-reverse.png")
		else:
			logo = pygame.image.load("tud/scaled.tudlogo.png")

		# 2133x626 orig
		# -> 156x46 in 1000x750
		# -> 164x48 in 1024x768?
		# -> 213x62? (ist 49x14 größer)
		#
		# :: 36x13 größer, 19 nach links
		logo = pygame.transform.scale(logo, (200, 59))
		screen.blit(logo, (44, 50))

		fontface = "Helvetica" # Verdana?
		font = pygame.font.SysFont(fontface, 14)
		bfont = pygame.font.SysFont(fontface, 14)
		bfont.set_bold(1)
		introfont = pygame.font.SysFont(fontface, 50)
		introfont.set_bold(0)
		datefont = pygame.font.SysFont(fontface, 30)

		chapterfont = pygame.font.SysFont(fontface, 28)
		headingfont = pygame.font.SysFont(fontface, 22)
		headingfont.set_bold(1)
		textfont = pygame.font.SysFont(fontface, 18)

		institutex = 110

		if self.title.faculty:
			f = bfont.render(self.title.faculty, 1, bannerforecolor)
			screen.blit(f, (110, 130))
			institutex += f.get_width() + 2

		if self.title.institute:
			f = font.render(self.title.institute, 1, bannerforecolor)
			screen.blit(f, (institutex, 130))

		if coverpage:
			if self.title.title:
				f = introfont.render(self.title.title, 1, forecolor)
				screen.blit(f, (110, 290))

			conty = 360
			for titlecont in self.title.titlecont:
				f = introfont.render(titlecont, 1, forecolor)
				screen.blit(f, (110, conty))
				conty += 70

			if self.title.author:
				f = datefont.render(self.title.author, 1, forecolor)
				screen.blit(f, (110, 580))

			if self.title.dateloc:
				f = datefont.render(self.title.dateloc, 1, forecolor)
				screen.blit(f, (110, 640))
		else:
			f = font.render(self.title.dateloc, 1, forecolor)
			screen.blit(f, (110, 700))

			title = ""
			if self.title.title:
				title = self.title.title
			for titlecont in self.title.titlecont:
				title += " " + titlecont
			f = font.render(title, 1, forecolor)
			x = 510 - f.get_width() / 2
			screen.blit(f, (x, 700))

			curpage = str(page)
			maxpage = str(self.pages)
			f = font.render("Slide " + curpage + " of " + maxpage, 1, forecolor)
			screen.blit(f, (790, 700))

		if not coverpage:
			slide = self.slides[page - 2]
			y = 200

			if slide.chapter:
				f = chapterfont.render(slide.chapter, 1, forecolor)
				screen.blit(f, (110, y))
				y += 40

			#if slide.heading:
			#	f = headingfont.render(slide.heading, 1, altforecolor)
			#	screen.blit(f, (110, y))
			#	y += 40

			headingidx = 0

			for line in slide.text:
				if line is not None:
					f = textfont.render(line, 1, altforecolor)
					screen.blit(f, (110, y))
					y += 30
				else:
					heading = slide.headings[headingidx]
					f = headingfont.render(heading, 1, altforecolor)
					screen.blit(f, (110, y))
					y += 40
					headingidx += 1

	def interactive(self, event):
		if event.type == KEYDOWN:
			key = event.key
			if key == K_ESCAPE or pygame.event.peek(QUIT):
				return "exit"
			if key == K_RETURN:
				return "next"
			if key == K_BACKSPACE:
				return "previous"

component = TUD()

parameters = (
	("title", "Title page information", None),
	("slides", "Slides content", None)
)

metainfo = {
	"version": "0.1",
	"author": "Josef Spillner",
	"authoremail": "<josef@coolprojects.org>",
	"licence": "GPL (but design is protected)"
}

doc = """
TUD: slides in corporate design of Dresden University of Technology
"""

